# Software Bill of Materials (SBOM)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom#overview)
  * [Step 1: Generate SBOMs](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom#step-1:-generate-sboms)
  * [Step 2: Upload SBOMs Through the API](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom#step-2:-upload-sboms-through-the-api)
  * [Step 3: View SBOMs in the SBOM Explorer](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom#step-3:-view-sboms-in-the-sbom-explorer)
  * [Permissions](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom#permissions)
  * [Additional Resources](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom#additional-resources)


To understand and manage dependencies among your microservices, generate SBOM files and ingest them into SAP LeanIX using our API.
